==> js-language-23.1.1-sources.jar: com/oracle/truffle/js/runtime/builtins/JSAsyncGeneratorObject.java <==
/*
 * Copyright (c) 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.runtime.builtins;

import java.util.ArrayDeque;

import com.oracle.truffle.api.CallTarget;
import com.oracle.truffle.api.frame.MaterializedFrame;
import com.oracle.truffle.api.object.Shape;
import com.oracle.truffle.js.runtime.objects.AsyncGeneratorRequest;
import com.oracle.truffle.js.runtime.objects.JSDynamicObject;
import com.oracle.truffle.js.runtime.objects.JSNonProxyObject;

public final class JSAsyncGeneratorObject extends JSNonProxyObject {

    private JSFunction.AsyncGeneratorState asyncGeneratorState;
    private MaterializedFrame asyncGeneratorContext;
    private CallTarget asyncGeneratorTarget;
    private ArrayDeque<AsyncGeneratorRequest> asyncGeneratorQueue;
    private Object generatorBrand;

    protected JSAsyncGeneratorObject(Shape shape, JSDynamicObject proto) {
        super(shape, proto);
    }

    public JSFunction.AsyncGeneratorState getAsyncGeneratorState() {
        return asyncGeneratorState;
    }

    public void setAsyncGeneratorState(JSFunction.AsyncGeneratorState asyncGeneratorState) {
        this.asyncGeneratorState = asyncGeneratorState;
    }

    public MaterializedFrame getAsyncGeneratorContext() {
        return asyncGeneratorContext;
    }

    public void setAsyncGeneratorContext(MaterializedFrame asyncGeneratorContext) {
        this.asyncGeneratorContext = asyncGeneratorContext;
    }

    public CallTarget getAsyncGeneratorTarget() {
        return asyncGeneratorTarget;
    }

    public void setAsyncGeneratorTarget(CallTarget asyncGeneratorTarget) {
        this.asyncGeneratorTarget = asyncGeneratorTarget;
    }

    public ArrayDeque<AsyncGeneratorRequest> getAsyncGeneratorQueue() {
        return asyncGeneratorQueue;
    }

    public void setAsyncGeneratorQueue(ArrayDeque<AsyncGeneratorRequest> asyncGeneratorQueue) {
        this.asyncGeneratorQueue = asyncGeneratorQueue;
    }

    public boolean hasGeneratorBrand() {
        return generatorBrand != null;
    }

    public Object getGeneratorBrand() {
        return generatorBrand;
    }

    public void setGeneratorBrand(Object generatorBrand) {
        this.generatorBrand = generatorBrand;
    }
}

==> js-language-24.1.0-sources.jar: com/oracle/truffle/js/runtime/builtins/JSAsyncGeneratorObject.java <==
/*
 * Copyright (c) 2023, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.runtime.builtins;

import java.util.ArrayDeque;

import com.oracle.truffle.api.CallTarget;
import com.oracle.truffle.api.frame.MaterializedFrame;
import com.oracle.truffle.api.object.Shape;
import com.oracle.truffle.api.strings.TruffleString;
import com.oracle.truffle.js.runtime.objects.AsyncGeneratorRequest;
import com.oracle.truffle.js.runtime.objects.JSDynamicObject;
import com.oracle.truffle.js.runtime.objects.JSNonProxyObject;

public final class JSAsyncGeneratorObject extends JSNonProxyObject {

    private JSFunction.AsyncGeneratorState asyncGeneratorState;
    private MaterializedFrame asyncGeneratorContext;
    private CallTarget asyncGeneratorTarget;
    private ArrayDeque<AsyncGeneratorRequest> asyncGeneratorQueue;
    private Object generatorBrand;

    protected JSAsyncGeneratorObject(Shape shape, JSDynamicObject proto) {
        super(shape, proto);
    }

    public JSFunction.AsyncGeneratorState getAsyncGeneratorState() {
        return asyncGeneratorState;
    }

    public void setAsyncGeneratorState(JSFunction.AsyncGeneratorState asyncGeneratorState) {
        this.asyncGeneratorState = asyncGeneratorState;
    }

    public MaterializedFrame getAsyncGeneratorContext() {
        return asyncGeneratorContext;
    }

    public void setAsyncGeneratorContext(MaterializedFrame asyncGeneratorContext) {
        this.asyncGeneratorContext = asyncGeneratorContext;
    }

    public CallTarget getAsyncGeneratorTarget() {
        return asyncGeneratorTarget;
    }

    public void setAsyncGeneratorTarget(CallTarget asyncGeneratorTarget) {
        this.asyncGeneratorTarget = asyncGeneratorTarget;
    }

    public ArrayDeque<AsyncGeneratorRequest> getAsyncGeneratorQueue() {
        return asyncGeneratorQueue;
    }

    public void setAsyncGeneratorQueue(ArrayDeque<AsyncGeneratorRequest> asyncGeneratorQueue) {
        this.asyncGeneratorQueue = asyncGeneratorQueue;
    }

    public boolean hasGeneratorBrand() {
        return generatorBrand != null;
    }

    public Object getGeneratorBrand() {
        return generatorBrand;
    }

    public void setGeneratorBrand(Object generatorBrand) {
        this.generatorBrand = generatorBrand;
    }

    @Override
    public TruffleString getClassName() {
        return JSAsyncGenerator.CLASS_NAME;
    }
}
